@@ -20,7 +20,7 @@ class EventBus(object):
                 event = self.__eventQueue.get()  
                 self.__event_process(event)
             except Exception as e:
-                logger.error('event bus execute exception',e)
+                logger.exception(e)
 
     def __event_process(self, event):
         """处理事件"""
@@ -51,11 +51,11 @@ class EventBus(object):
     def remove_listener(self, event_type, handler):
         """移除监听器的处理函数"""
         try:
-            handlerList = self.handlers[event_type]
+            handlerList = self.__handlers[event_type]
             if handler in handlerList:
                 handlerList.remove(handler)
             if not handlerList:
-                del self.handlers[event_type]
+                del self.__handlers[event_type]
         except KeyError:
             pass
 
@@ -64,6 +64,8 @@ class EventBus(object):
         self.__eventQueue.put(event)
 
 class Event(object):
+    # 事件类
+
     def __init__(self, event_type, **kwargs):
         self.__dict__ = kwargs
         self.event_type = event_type
