@@ -2,6 +2,7 @@
 import numpy as np
 from iqsopenapi import *
 import datetime
+import talib
 
 def on_init(ctx):
     #variables
@@ -131,14 +132,14 @@ config = {
     "runtime":"DEBUG",
     "run_type":"LIVE_TRADING",
     "log":{
-            'level':'INFO',
+            'level':'DEBUG',
             'file' :r"D:\logs\test\strategy.log",
         },
     #"ext_notify":{
     #        "type":"websocket",
     #        "address":"ws://localhost:14002/"
     #    },
-    #"acct_info":{
+    # "acct_info":{
     #        "strategy_id":"21",
     #        "account":"10030"
     #    }
