@@ -53,15 +53,16 @@ class PaperTradeApi(ITradeApi):
                 subRet = self.Subscribe(*self.__subscribes)
                 logger.debug("连接成功，订阅完成：{0}".format(subRet))
         except Exception as e:
-            logger.error('paper trade subscribe exception',e)
+            logger.exception(e)
 
     def __Subscribe(self):
         id = uuid.uuid1().hex
         req = {"RequestType":RequestType.Subscribe,"ReqID":id,"StrategyId":self.__strategy_id,"TradeAccount":self.__account_id}
         message = json.dumps(req,ensure_ascii=False)
         if not self.__Send(id,message):
-            logger.error("send fail:{0}".format(message))
+            logger.error("Subscribe papertrade send fail:{0}".format(message))
             return False
+        logger.info("Subscribe papertrade succeed:{0}".format(message))
         return True
 
     def __Send(self,id,msg):
