@@ -2,6 +2,7 @@
 import sys
 import time
 import logging
+from logging import handlers
 from datetime import datetime
 import os
 
@@ -19,15 +20,14 @@ def log2file(filename):
     path = os.path.dirname(filename)
     if not os.path.exists(path):
         os.makedirs(path)
-    file_handler = logging.FileHandler(filename)
-    file_handler.setLevel(logging.DEBUG)
-    file_handler.setFormatter(logformat)
-    logger.addHandler(file_handler)
+    trfh = handlers.TimedRotatingFileHandler(filename=filename,when='D',backupCount=30,encoding='utf-8')
+    trfh.setLevel(logging.DEBUG)
+    trfh.setFormatter(logformat)
+    logger.addHandler(trfh)
 
 if __name__ == '__main__':
-    
-    log2file();
 
+    log2file(r"D:\logs\test\strategy.log")
     logger.error("test error")
     logger.critical("test critical")
     logger.debug("test debug")
